screen = {
		w = love.graphics.getWidth(),
		h = love.graphics.getHeight()
	}

if true then
	G = 10^5
	amount = 30
else
	G = 10^3
	amount = 450
end

function love.load()
	love.math.setRandomSeed(love.timer.getTime())

	objects = {}
	connections = {}
	local sizes = {2,2,2,2,2,2,3,3,3,3,3,4,4,4,4,5,8,10,16}
	for id_object = 1, amount do
		local size = sizes[math.random(#sizes)]
		local x = math.random(size+10, screen.w-size)
		local y = math.random(size+10, screen.h-size)
		objects[id_object] = {x=x, y=y, size = size, speed={x=0,y=0}, force={x=0,y=0}, last_force={x=0,y=0}, 
			color = {math.random(127, 255)/255, math.random(127, 255)/255, math.random(127, 255)/255, 1}}
	end
	print ('objects: ' .. #objects)
	
	for id_object_a = 1, (amount-1) do
		for id_object_b = (id_object_a+1), amount do
			if objects[id_object_a] and objects[id_object_b] then
				connections[#connections+1] = {id_object_a, id_object_b}
			end
		end
	end
	print ('connections: ' .. #connections)
end

function update_force (connection, dt)
	local a = objects[connection[1]]
	local b = objects[connection[2]]
	local dx = a.x-b.x
	local dy = a.y-b.y
	local sd = (dx^2 + dy^2) -- distance is already square
	if sd > 10 then
		local alpha = math.atan2(dy, dx)
		local m1 = a.size
		local m2 = b.size
	--	local force = G*m1*m2/sd
	--	print (dx)
		local f_x = G*m1*m2/(sd) * math.cos(alpha)
		local f_y = G*m1*m2/(sd) * math.sin(alpha)
		
		a.force.x = a.force.x - f_x
		a.force.y = a.force.y - f_y
		
		b.force.x = b.force.x + f_x
		b.force.y = b.force.y + f_y
	end
end

function update_speed (object, dt)
	object.speed.x = object.speed.x + dt*object.force.x/(object.size)^2
	object.speed.y = object.speed.y + dt*object.force.y/(object.size)^2
	object.last_force = {x=object.force.x, y=object.force.y}
	object.force = {x=0,y=0}
--	print (object.speed.x)
end

function update_position (object, dt)

	if object.x < (object.size) then 
		object.speed.x = math.abs(object.speed.x )/2
	elseif object.x > (screen.w-object.size) then
		object.speed.x = -math.abs(object.speed.x )/2
	end
	if object.y < (object.size) then 
		object.speed.y = math.abs(object.speed.y)/2
	elseif object.y > (screen.h-object.size) then
		object.speed.y = -math.abs(object.speed.y)/2
	end
	object.x = object.x + dt*object.speed.x
	object.y = object.y + dt*object.speed.y
end

function love.update(dt)
	for id_connection, connection in pairs (connections) do
		update_force (connection, dt)
	end
	
	for id_object, object in pairs (objects) do
		update_speed (object, dt)
		update_position (object, dt)
	end
	
end


function love.draw()
	for id_object, object in pairs (objects) do
		love.graphics.setColor(object.color)
		love.graphics.circle("fill", object.x, object.y, object.size)

		love.graphics.line(object.x, object.y, object.x-object.speed.x/10, object.y-object.speed.y/10)
		
		-- forces, just disabled
--		love.graphics.setColor(1,0,0,1)
--		love.graphics.line(object.x, object.y, object.x+object.last_force.x*10^(-2), object.y+object.last_force.y*10^(-2))

		love.graphics.setColor(1,1,1,1)
		love.graphics.points(object.x, object.y)
	end
	love.graphics.setColor(1,1,1,1)
	love.graphics.print("Current FPS: "..tostring(love.timer.getFPS( )), 10, 10)
--	print(objects[1].x)
end